@@ -1,9 +1,4 @@
 import requests
-from firstimpression.api.bbc import *
-from firstimpression.api.ns import *
-from firstimpression.api.nu_nl import *
-from firstimpression.api.traffic import *
-
 
 
 def request(url, header=None, params=None):
